document.addEventListener('DOMContentLoaded', () => {
  // Mobile menu functionality
  const menuBtn = document.querySelector('.mobile-menu-btn');
  const navLinks = document.querySelector('.nav-links');

  menuBtn.addEventListener('click', () => {
    navLinks.classList.toggle('active');
    const spans = menuBtn.querySelectorAll('span');
    spans[0].style.transform = navLinks.classList.contains('active') 
      ? 'rotate(45deg) translate(5px, 6px)' 
      : 'none';
    spans[1].style.opacity = navLinks.classList.contains('active') 
      ? '0' 
      : '1';
    spans[2].style.transform = navLinks.classList.contains('active') 
      ? 'rotate(-45deg) translate(5px, -6px)' 
      : 'none';
  });

  // Smooth scroll for anchor links
  document.querySelectorAll('a[href^="#"]').forEach(anchor => {
    anchor.addEventListener('click', function (e) {
      e.preventDefault();
      const target = document.querySelector(this.getAttribute('href'));
      target.scrollIntoView({
        behavior: 'smooth'
      });
      // Close mobile menu if open
      navLinks.classList.remove('active');
    });
  });

  // Form submission
  const form = document.getElementById('quote-form');
  form.addEventListener('submit', (e) => {
    e.preventDefault();
    // Collect form data
    const formData = {
      name: document.getElementById('name').value,
      email: document.getElementById('email').value,
      phone: document.getElementById('phone').value,
      message: document.getElementById('message').value
    };
    
    // Here you would typically send the data to a server
    console.log('Form submitted:', formData);
    alert('Thank you for your inquiry! We will contact you shortly.');
    form.reset();
  });

  // Intersection Observer for fade-in animations
  const observer = new IntersectionObserver((entries) => {
    entries.forEach(entry => {
      if (entry.isIntersecting) {
        entry.target.style.opacity = '1';
        entry.target.style.transform = 'translateY(0)';
      }
    });
  }, { threshold: 0.1 });

  // Observe all sections except hero
  document.querySelectorAll('section:not(.hero)').forEach(section => {
    section.style.opacity = '0';
    section.style.transform = 'translateY(20px)';
    section.style.transition = 'all 0.6s ease-out';
    observer.observe(section);
  });
});